#
# spec file for package libSavitar
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
Name:           libSavitar
%define sversion        4.13.0
Version:        4.13.1
Release:        2.12
Summary:        C++ implementation of 3mf loading with SIP python bindings
License:        LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/Ultimaker/libSavitar
Source:         https://github.com/Ultimaker/libSavitar/archive/%{sversion}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE -- Use system libraries instead of embedded ones.
Patch0:         use-system-libs.patch
BuildRequires:  cmake >= 2.8.12
BuildRequires:  gmock
BuildRequires:  gtest
BuildRequires:  pugixml-devel >= 1.8
BuildRequires:  python3-sip-devel < 5
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} > 150300
BuildRequires:  python3-qt5-sip
%else
BuildRequires:  python3-sip
%endif

%description
libSavitar is a C++ implementation of 3mf loading with SIP python bindings.

%package -n %{name}%{sover}
Summary:        3D printer control software
Group:          System/Libraries
Provides:       python3-Savitar = %version
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} > 150300
# The PyQt5.sip module. NOT a requirement on (Py)Qt5
Requires:       python3-qt5-sip
%else
# python3-sip provides PyQt5.sip in older distributions only
Requires:       python3-sip
%endif

%description -n %{name}%{sover}
libSavitar is a C++ implementation of 3mf loading with SIP python bindings.

%package devel
Summary:        Header files for libSavitar
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}
Requires:       python3-sip-devel < 5

%description devel
Development package for libSavitar.

%prep
%autosetup -p1 -n %{name}-%{sversion}

%build
%cmake -DUSE_SYSTEM_LIBS=TRUE \
       -DBUILD_TESTS=TRUE \
       -DLIB_SUFFIX=64
%cmake_build

%install
%cmake_install

%check
cd build
export LD_LIBRARY_PATH=$PWD
# we don't use "make test" to get the output on failure
/usr/bin/ctest --force-new-ctest-process --output-on-failure

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files devel
%{_includedir}/Savitar/
%{_libdir}/cmake/Savitar/
%{_libdir}/libSavitar.so

%files -n %{name}%{sover}
%license LICENSE
%doc README.md
%{_libdir}/libSavitar.so.*
%{python3_sitearch}/Savitar.so

%changelog
* Sat Feb 26 2022 Max Lin <mlin@suse.com>
- Use BuildRequires python3-qt5-sip for Leap 15.4
* Sun Feb  6 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.13.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.13.1
* Thu Jan 27 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- update to 4.13.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.13.0
- Drop upstreamed patch:
  * libSavitar-3.5.1-PyQt5.sip.patch
* Mon Apr 26 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.9.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.9
* Sun Nov 22 2020 Benjamin Greiner <code@bnavigator.de>
- Depend on the PyQt5.sip module (see sr#849990 for libArcus)
- Refresh libSavitar-3.5.1-PyQt5.sip.patch to query correct module
  for version
* Sat Nov 21 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Depend on python3-sip < 5, as libSavitar build is incompatible
  with SIP 5 and upstream currently has no intention to update,
  see gh#Ultimaker/libSavitar#26.
* Tue Nov 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.8.0
  * no code changes, just some build system churn.
* Sun Jun  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 4.6.1
  * mostly internal changes
- Fix Savitar python import error with current PyQt5, add
  libSavitar-3.5.1-PyQt5.sip.patch
* Thu Jan  2 2020 Adrian Schröter <adrian@suse.de>
- update to version 4.4.1
  * mostly internal changes
* Wed Jun 26 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.1.0
  * https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
- enable test cases
* Fri Nov 23 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.6.0
  * version change only
* Wed Oct 17 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.5.1
  * version change only
* Wed Aug  8 2018 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
- Fix RPM groups for Factory.
* Mon Aug  6 2018 adrian@suse.de
- update to version 3.4.1
* Mon May 14 2018 christophe@krop.fr
- Initial package.
